@@ -788,13 +788,11 @@ void KSignalPlotterPrivate::calculateNiceRange()
 {
     qreal max = mUserMaxValue;
     qreal min = mUserMinValue;
-    bool minFromUser = true;
     if( mUseAutoRange ) {
         if(!isnan(mMaxValue) && mMaxValue * 0.99 > max)  //Allow max value to go very slightly over the given max, for rounding reasons
             max = mMaxValue;
         if(!isnan(mMinValue) && mMinValue * 0.99 < min) {
             min = mMinValue;
-            minFromUser = false;
         }
     }
 
